@@ -368,7 +368,7 @@ def format_annotation(annotation):
 
     Displaying complex types from ``typing`` relies on its private API.
     """
-    if typing and isinstance(annotation, typing.TypeVar):  # type: ignore
+    if typing and isinstance(annotation, typing.TypeVar):
         return annotation.__name__
     if annotation == Ellipsis:
         return '...'
@@ -971,7 +971,6 @@ class Documenter(object):
                     # keep documented attributes
                     keep = True
                 isattr = True
-                print(membername, keep)
             elif want_all and membername.startswith('_'):
                 # ignore members whose name starts with _ by default
                 keep = self.options.private_members and \
